**Sample Package**

.. image:: https://upload.wikimedia.org/wikipedia/commons/6/6b/WhatsApp.svg
   :align: center
   :height: 200
   :alt: logo  
  
.. image:: https://img.shields.io/pypi/v/dummypackage12624.svg
    :target: https://pypi.org/project/dummypackage12624/

.. image:: https://img.shields.io/pypi/pyversions/dummypackage12624.svg
    :target: https://pypi.org/project/dummypackage12624/

.. image:: https://github.com/ronylpatil/test_package/actions/workflows/ci.yaml/badge.svg
    :target: https://github.com/ronylpatil/test_package/actions?query=workflow%3Atest

.. image:: https://github.com/ronylpatil/test_package/actions/workflows/cd.yml/badge.svg
    :target: https://github.com/ronylpatil/test_package/actions?query=workflow%3Atest


The ``package`` basic information.

A simple code example:

.. code-block:: python

    # content of test_sample.py
    # code should be automatically fetched

To execute it::

   # execution code here
   
   # code ends here

Add basic info here.


Features
--------
- Feature_1
- Feature_2
- Feature_3
- Feature_3

Documentation
-------------
For full documentation, including installation, tutorials and PDF documents, please see https://docs.pytest.org/en/stable/.

Bugs/Requests
-------------
Please use the `GitHub issue tracker <https://github.com/pytest-dev/pytest/issues>`_ to submit bugs or request features.

Changelog
---------
Consult the `Changelog <https://docs.pytest.org/en/stable/changelog.html>`__ page for fixes and enhancements of each version.

License
-------
Distributed under the terms of the `MIT`_ license.

.. _`MIT`: https://github.com/ronylpatil/test_package/LICENSE
